"use strict";

Object.defineProperty(exports, "__esModule", {
    value: true
});

var _remark = require("remark");

var _remark2 = _interopRequireDefault(_remark);

var _remarkHtml = require("remark-html");

var _remarkHtml2 = _interopRequireDefault(_remarkHtml);

var _removeMarkdown = require("remove-markdown");

var _removeMarkdown2 = _interopRequireDefault(_removeMarkdown);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var ast = function ast(input) {
    return typeof input === 'string' && !isMdast(input) ? (0, _remark2.default)().parse(input) : input;
};

var text = function text(input) {
    if (!input) return;

    if (isMdast(input)) {
        input = md(input);
    }

    return (0, _removeMarkdown2.default)(input).trim();
};

var html = function html(input) {
    if (!input) return;

    if (isMdast(input)) {
        input = md(input);
    }

    return (0, _remark2.default)().use(_remarkHtml2.default).process(input).contents.trim();
};

var md = function md(input) {
    if (!input) return;

    if (isMdast(input)) {
        input = (0, _remark2.default)().stringify(input);
    }

    return input.trim();
};

// shortcuts
var isType = function isType(node, type) {
    return node.type === type;
};
var isDepth = function isDepth(node, depth) {
    return node.depth === depth;
};
var hasChildren = function hasChildren(node) {
    return node.children ? true : false;
};

var isRoot = function isRoot(node) {
    return isType(node, "root");
};
var isParagraph = function isParagraph(node) {
    return isType(node, "paragraph");
};
var isBlockquote = function isBlockquote(node) {
    return isType(node, 'blockquote');
};
var isHeading = function isHeading(node) {
    return isType(node, 'heading');
};
var isCode = function isCode(node) {
    return isType(node, 'code');
};
var isInlineCode = function isInlineCode(node) {
    return isType(node, 'inlineCode');
};
var isYaml = function isYaml(node) {
    return isType(node, 'yaml');
};
var isHtml = function isHtml(node) {
    return isType(node, 'html');
};
var isList = function isList(node) {
    return isType(node, 'list');
};
var isListItem = function isListItem(node) {
    return isType(node, 'listItem');
};
var isTable = function isTable(node) {
    return isType(node, 'table');
};
var isTableRow = function isTableRow(node) {
    return isType(node, 'tableRow');
};
var isTableCell = function isTableCell(node) {
    return isType(node, 'tableCell');
};
var isThematicBreak = function isThematicBreak(node) {
    return isType(node, 'thematicBreak');
};
var isBreak = function isBreak(node) {
    return isType(node, 'break');
};
var isEmphasis = function isEmphasis(node) {
    return isType(node, 'emphasis');
};
var isStrong = function isStrong(node) {
    return isType(node, 'strong');
};
var isDelete = function isDelete(node) {
    return isType(node, 'delete');
};
var isLink = function isLink(node) {
    return isType(node, 'link');
};
var isImage = function isImage(node) {
    return isType(node, 'image');
};
var isFootnote = function isFootnote(node) {
    return isType(node, 'footnote');
};
var isLinkReference = function isLinkReference(node) {
    return isType(node, 'linkReference');
};
var isImageReference = function isImageReference(node) {
    return isType(node, 'imageReference');
};
var isFootnoteReference = function isFootnoteReference(node) {
    return isType(node, 'footnoteReference');
};
var isDefinition = function isDefinition(node) {
    return isType(node, 'definition');
};
var isFootnoteDefinition = function isFootnoteDefinition(node) {
    return isType(node, 'footnoteDefinition');
};
var isText = function isText(node) {
    return isType(node, 'text');
};

// special
var isMdast = function isMdast(input) {
    if (!input) return;

    return isRoot(input) || hasChildren(input);
};

exports.default = {
    // helpers
    ast: ast, text: text, html: html, md: md,

    // shortcuts
    isType: isType, isDepth: isDepth, hasChildren: hasChildren,
    isRoot: isRoot, isParagraph: isParagraph, isBlockquote: isBlockquote, isHeading: isHeading, isCode: isCode, isInlineCode: isInlineCode,
    isYaml: isYaml, isHtml: isHtml, isList: isList, isListItem: isListItem, isTable: isTable, isTableRow: isTableRow, isTableCell: isTableCell,
    isThematicBreak: isThematicBreak, isBreak: isBreak, isEmphasis: isEmphasis, isStrong: isStrong, isDelete: isDelete, isLink: isLink, isImage: isImage,
    isFootnote: isFootnote, isLinkReference: isLinkReference, isImageReference: isImageReference, isFootnoteReference: isFootnoteReference,
    isDefinition: isDefinition, isFootnoteDefinition: isFootnoteDefinition, isText: isText
};
module.exports = exports["default"];

